==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-wx/Class_wx_GridSizer.h <==
//----------------------------------------------------------------------------
// wxGridSizer
// extracted from gridsizr.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_GRIDSIZER_H__
#define __CLASS_WX_GRIDSIZER_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxGridSizer
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_GridSizer);

//----------------------------------------------------------------------------
// Object declaration for wxGridSizer
//----------------------------------------------------------------------------
class Object_wx_GridSizer : public Object_wx_Sizer {
public:
	Gura_DeclareObjectAccessor(wx_GridSizer)
public:
	inline Object_wx_GridSizer(wxGridSizer *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Sizer(Gura_UserClass(wx_GridSizer), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_GridSizer(Class *pClass, wxGridSizer *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Sizer(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_GridSizer();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxGridSizer *GetEntity() {
		return dynamic_cast<wxGridSizer *>(_pEntity);
	}
	inline wxGridSizer *ReleaseEntity() {
		wxGridSizer *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal sig) const {
		if (_pEntity != NULL) return false;
		SetError_InvalidWxObject(sig, "wxGridSizer");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-wx/Class_wx_GridSizer.h <==
//----------------------------------------------------------------------------
// wxGridSizer
// extracted from gridsizr.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_GRIDSIZER_H__
#define __CLASS_WX_GRIDSIZER_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxGridSizer
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_GridSizer);

//----------------------------------------------------------------------------
// Object declaration for wxGridSizer
//----------------------------------------------------------------------------
class Object_wx_GridSizer : public Object_wx_Sizer {
public:
	Gura_DeclareObjectAccessor(wx_GridSizer)
public:
	inline Object_wx_GridSizer(wxGridSizer *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Sizer(Gura_UserClass(wx_GridSizer), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_GridSizer(Class *pClass, wxGridSizer *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Sizer(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_GridSizer();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxGridSizer *GetEntity() {
		return dynamic_cast<wxGridSizer *>(_pEntity);
	}
	inline wxGridSizer *ReleaseEntity() {
		wxGridSizer *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal &sig) const {
		if (_pEntity != nullptr) return false;
		SetError_InvalidWxObject(sig, "wxGridSizer");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif
